@@ -1,10 +1,10 @@
 __author__ = 'Victor Polevoy'
 __title__ = 'qllauncher'
-__version__ = '0.6.1.4'
+__version__ = '0.6.1.5'
 __license__ = 'GPL v3'
 __copyright__ = 'Copyright 2014 Victor Polevoy'
 
-from qllauncher.qlnetwork import QLNetwork
+from qllauncher.qlnetwork import QLNetwork, NetworkStatusListener
 from qllauncher.qlxmpp import QLXMPP, QLXMPPFrontend
 from qllauncher.qlhandle import QLHandle
 from qllauncher.qlprofile import *
